# graph plotting of a Zoom session using gnuplot on Linux

set terminal png

# draw the connection profile plot
# (shows the connections monotonically upward as they occurred,
#  with a horizontal line showing the start, duration, and end of each)
set output 'conn.png'
set key top left
#set key bottom right
set title "Zoom Session Profile: Connection-based View"
set xlabel 'Time (seconds)'
#set xlabel 'Time (minutes)'
set ylabel 'Connection ID'

plot [0:][0:] 'tcp.dat' using 1:2:10:11 with xerrorbars title "TCP" lw 2, \
              'udp.dat' using 1:2:10:11 with xerrorbars title "UDP" lw 2, \
              'icmp.dat' using 1:2 with points title "ICMP" lw 2, \


# draw the port profile plot
# (shows the connections based on their transport-layer port numbers,
#  with a horizontal line showing the start, duration, and end of each)
set output 'port.png'
set title "Zoom Session Profile: Port-based View"
set ylabel 'Client Port Number'
set nokey

plot [0:][0:] 'tcp.dat' using 1:5:10:11 with xerrorbars title "TCP" lw 2, \
              'udp.dat' using 1:5:10:11 with xerrorbars title "UDP" lw 2, \
              'icmp.dat' using 1:5 with points title "ICMP" lw 2, \

# draw the IP profile plot
# (shows the connections based on their client IP address,
#  with a horizontal line showing the start, duration, and end of each conn,
#  and a vertical displacement to separate TCP from UDP)
set output 'ip.png'
set nokey
set title "Zoom Session Profile: IP-based View"
set ylabel 'Distinct Client IP'

plot [0:][0:] 'tcp.dat' using 1:3:10:11 with xerrorbars title "TCP" lw 2, \
              'udp.dat' using 1:3:10:11 with xerrorbars title "UDP" lw 2, \
              'icmp.dat' using 1:3 with points title "ICMP" lw 2, \


# draw scatterplot to see patterns for average packet sizes
set output 'sizes.png'
set title "Scatterplot of Zoom Connections"
set xlabel "Average Packet Size Sent"
set ylabel "Average Packet Size Received"
set key top left

# uncomment the next line if you want to draw this graph
#plot [0:][0:] 'udpV.dat' using 17:18 title "Video" w p, 'udpA.dat' using 17:18 title "Audio" w p, 'udpD.dat' using 17:18 title "Data" w p, 'tcp.dat' using 17:18 title "Control" w p

# draw scatterplot to see patterns for average packet rates
set output 'rates.png'
set xlabel "Average Packets Sent per Second"
set ylabel "Average Packets Received per Second"

# uncomment the next line if you want to draw this graph
#plot [0:][0:] 'udpV.dat' using 19:20 title "Video" w p, 'udpA.dat' using 19:20 title "Audio" w p, 'udpD.dat' using 19:20 title "Data" w p, 'tcp.dat' using 19:20 title "Control" w p

